Créer un nouveau compte client
Description: Micromania
Keywords: micromania

Menu
Micromania

- - Nos magasins
  - Nos services
  - Nos dossiers
  - Web TV
- Search site:
- Mon compte
- Panier 0

# Mon compte Votre compte vous permet de suivre vos commandes et de gérer vos préférences.

## Créez votre compte internet Micromania.fr

Remplissez les champs ci-dessous pour créer votre compte Micromania

- *Civilité:
  Mr Mme Mlle
- *Nom
  *Prénom

- *Adresse email
- *Confirmation d'adresse email
- *Créez votre mot de passe
  *Confirmez le mot de passe

- Vous possédez une Megacarte ?

- * Nom de famille

- * Code postal
  * Numéro de membre

- * Date de naissance

Afin d'associer votre Megacarte à votre compte, vous devez indiquer au choix votre code postal ou votre date de naissance.

* Champs obligatoires